@@ -43,27 +43,56 @@ export default {
       defaultValue: {
         length: 30
       }
+    },
+    flip_orizzontal: {
+      label: "flip orizzontale",
+      type: "checkbox",
+      defaultValue: false,
+      values: {
+        'none': false,
+        'yes':  true
+      }
     }
   },
 
   render2D: function (element, layer, scene) {
     const STYLE_HOLE_BASE = {stroke: "#000", strokeWidth: "3px", fill: "#000"};
-    const STYLE_HOLE_SELECTED = {stroke: "#0096fd", strokeWidth: "3px", fill: "#0096fd", cursor: "move"};
-    //let line = layer.lines.get(hole.line);
-    //let epsilon = line.properties.get('thickness') / 2;
+    const STYLE_HOLE_SELECTED = {stroke: "#0096fd", strokeWidth: "4px", fill: "#0096fd", cursor: "move"};
+    const STYLE_ARC_BASE = {stroke: "#000", strokeWidth: "3px", strokeDasharray: "5,5", fill: "none"};
+    const STYLE_ARC_SELECTED = {stroke: "#0096fd", strokeWidth: "4px", strokeDasharray: "5,5", fill: "none", cursor: "move"};
 
     let epsilon = 3;
 
+    let flip = element.properties.get('flip_orizzontal');
     let holeWidth = element.properties.get('width').get('length');
     let holePath = `M${0} ${ -epsilon}  L${holeWidth} ${-epsilon}  L${holeWidth} ${epsilon}  L${0} ${epsilon}  z`;
+    let arcPath = `M${0},${0}  A${holeWidth},${holeWidth} 0 0,1 ${holeWidth},${holeWidth}`;
     let holeStyle = element.selected ? STYLE_HOLE_SELECTED : STYLE_HOLE_BASE;
+    let arcStyle = element.selected ? STYLE_ARC_SELECTED : STYLE_ARC_BASE;
     let length = element.properties.get('width').get('length');
-    return (
-      <g transform={`translate(${-length / 2}, 0)`}>
-        <path key="1" d={holePath} style={holeStyle}/>
-        <line key="2" x1={holeWidth / 2} y1={-10 - epsilon} x2={holeWidth / 2} y2={10 + epsilon} style={holeStyle}/>
-      </g>
-    );
+
+    if(flip == false) {
+      return (
+        <g transform={`translate(${-length / 2}, 0)`}>
+          <path key="1" d={arcPath} style={arcStyle}
+                transform={`translate(${0},${holeWidth}) scale(${1},${-1}) rotate(${0})`}/>
+          <line key="2" x1={0} y1={holeWidth - epsilon} x2={0} y2={0 - epsilon} style={holeStyle}
+                transform={`scale(${-1},${1})`}/>
+          <path key="5" d={holePath} style={holeStyle}/>
+        </g>
+      )
+    }
+    else{
+      return (
+        <g transform={`translate(${-length / 2}, 0)`}>
+          <path key="1" d={arcPath} style={arcStyle}
+                transform={`translate(${0},${-holeWidth}) scale(${1},${1}) rotate(${0})`}/>
+          <line key="2" x1={0} y1={-holeWidth - epsilon} x2={0} y2={0 - epsilon} style={holeStyle}
+                transform={`scale(${-1},${1})`}/>
+          <path key="5" d={holePath} style={holeStyle}/>
+        </g>
+      )
+    }
   },
 
   render3D: function (element, layer, scene) {
